Crate approximate

Crate approximate 

Structs

ScalableCounter
This represents an atomic counter that uses probability to achieve faster operations, while still retaining a good accuracy.

Traits

AtomicCounter
This trait represents all the possible operations on an ScalableCounter
AtomicVal
Countable