Structs
- Scalable
Counter - This represents an atomic counter that uses probability to achieve faster operations, while still retaining a good accuracy.
Traits
- Atomic
Counter - This trait represents all the possible operations on an ScalableCounter
- Atomic
Val - Countable